@@ -1637,7 +1637,8 @@ public:
     if (data.HasTime()) {
       std::wstring t=data.GetTime().GetLocalLocaleDateTime();
 
-      if (data.GetTimeDev()!=0) {
+      if (data.GetTimeDev()!=0 &&
+        finite(data.GetTimeDev())) {
         t+=L"\u00b1"+DoubleToString(data.GetTimeDev());
       }
 
@@ -1650,12 +1651,13 @@ public:
     if (data.HasLatitude()) {
       std::wstring l=DoubleToString(data.GetLatitude());
 
-      if (data.GetLatitudeDev()!=0) {
-        l+=L"\u00b1"+DoubleToString(data.GetLatitudeDev());
-      }
-
       l+=+L"\u00b0";
 
+      if (data.GetLatitudeDev()!=0 &&
+          finite(data.GetLatitudeDev())) {
+        l+=std::wstring(L"\u00b1")+DoubleToString(data.GetLatitudeDev())+L"m";
+      }
+
       latitude->Set(l);
     }
     else {
@@ -1665,12 +1667,13 @@ public:
     if (data.HasLongitude()) {
       std::wstring l=DoubleToString(data.GetLongitude());
 
-      if (data.GetLongitudeDev()!=0) {
-        l+=L"\u00b1"+DoubleToString(data.GetLongitudeDev());
-      }
-
       l+=+L"\u00b0";
 
+      if (data.GetLongitudeDev()!=0 &&
+          finite(data.GetLongitudeDev())) {
+        l+=std::wstring(L"\u00b1")+DoubleToString(data.GetLongitudeDev())+L"m";
+      }
+
       longitude->Set(l);
     }
     else {
@@ -1680,7 +1683,8 @@ public:
     if (data.HasAltitude()) {
       std::wstring a=DoubleToString(data.GetAltitude());
 
-      if (data.GetAltitudeDev()!=0) {
+      if (data.GetAltitudeDev()!=0 &&
+          finite(data.GetAltitudeDev())) {
         a+=L"\u00b1"+DoubleToString(data.GetAltitudeDev());
       }
 
@@ -1698,7 +1702,8 @@ public:
       if (data.GetSpeed()>=1/3.6) {
         s=DoubleToString(data.GetSpeed()*3600.0/1000);
 
-        if (data.GetSpeedDev()!=0) {
+        if (data.GetSpeedDev()!=0 &&
+            finite(data.GetSpeedDev())) {
           s+=L"\u00b1"+DoubleToString(data.GetSpeedDev()*3600.0/1000);
         }
 
@@ -1707,7 +1712,8 @@ public:
       else {
         s=DoubleToString(data.GetSpeed());
 
-        if (data.GetSpeedDev()!=0) {
+        if (data.GetSpeedDev()!=0 &&
+            finite(data.GetSpeedDev())) {
           s+=L"\u00b1"+DoubleToString(data.GetSpeedDev());
         }
 
@@ -1723,7 +1729,8 @@ public:
     if (data.HasTrack()) {
       std::wstring t=DoubleToString(data.GetTrack());
 
-      if (data.GetTrackDev()!=0) {
+      if (data.GetTrackDev()!=0 &&
+          finite(data.GetTrackDev())) {
         t+=L"\u00b1"+DoubleToString(data.GetTrackDev());
       }
 
@@ -1741,7 +1748,8 @@ public:
     if (data.HasClimb()) {
       std::wstring c=DoubleToString(data.GetClimb());
 
-      if (data.GetClimbDev()!=0) {
+      if (data.GetClimbDev()!=0 &&
+          finite(data.GetClimbDev())) {
         c+=L"\u00b1"+DoubleToString(data.GetClimbDev());
       }
 
@@ -1985,10 +1993,10 @@ static void gps_location_changed(LocationGPSDevice *device, gpointer userdata)
     gpsData.SetTime(time,fix->ept);
   }
   if (fix->fields & LOCATION_GPS_DEVICE_LATLONG_SET && !isnan(fix->latitude)) {
-    gpsData.SetLatitude(fix->latitude,fix->eph);
+    gpsData.SetLatitude(fix->latitude,fix->eph/100);
   }
   if (fix->fields & LOCATION_GPS_DEVICE_LATLONG_SET && !isnan(fix->longitude)) {
-    gpsData.SetLongitude(fix->longitude,fix->eph);
+    gpsData.SetLongitude(fix->longitude,fix->eph/100);
   }
   if (fix->fields & LOCATION_GPS_DEVICE_ALTITUDE_SET && !isnan(fix->altitude)) {
     gpsData.SetAltitude(fix->altitude,fix->epv);
