@@ -35,6 +35,9 @@ private:
 private:
   Lum::Model::DoubleDataStreamRef       model;
   Lum::OS::FontRef                      font;
+  Lum::OS::ColorRef                     backgroundColor;
+  Lum::OS::ColorRef                     lineColor;
+  Lum::OS::ColorRef                     textColor;
 
   size_t                                verticalScaleWidth;
   size_t                                digitWidth;
